Module coordinate

Module coordinate 

Parsing and printing for schema coordinates as described in the RFC.

Schema coordinates uniquely point to an item defined in a schema.

Structs

DirectiveArgumentCoordinate
A schema coordinate targeting a directive argument definition: @directive(argument:).
DirectiveCoordinate
A schema coordinate targeting a directive definition: @directive.
FieldArgumentCoordinate
A schema coordinate targeting a field argument definition: Type.field(argument:).
TypeAttributeCoordinate
A schema coordinate targeting a field definition or an enum value: Type.field, Enum.VALUE.
TypeCoordinate
A schema coordinate targeting a type definition: Type.

Enums

SchemaCoordinate
Any schema coordinate.
SchemaCoordinateLookup
Return type of SchemaCoordinate::lookup.
SchemaCoordinateParseError
Errors that can occur while parsing a schema coordinate.
SchemaLookupError
The error type for SchemaCoordinate::lookup and other lookup* methods.
TypeAttributeLookup
Return type of TypeAttributeCoordinate::lookup, for coordinates of the form Type.field.