Struct apollo_compiler::executable::FieldSet
source · pub struct FieldSet {
pub sources: SourceMap,
pub selection_set: SelectionSet,
}Expand description
FieldSet information created for FieldSet parsing in @requires directive.
Annotated with type information.
Fields
sources: SourceMapIf this document was originally parsed from a source file, this map contains one entry for that file and its ID.
The document may have been modified since.
selection_set: SelectionSetImplementations
sourceimpl FieldSet
impl FieldSet
sourcepub fn parse(
schema: &Valid<Schema>,
type_name: NamedType,
source_text: impl Into<String>,
path: impl AsRef<Path>
) -> Result<FieldSet, WithErrors<FieldSet>>
pub fn parse( schema: &Valid<Schema>, type_name: NamedType, source_text: impl Into<String>, path: impl AsRef<Path> ) -> Result<FieldSet, WithErrors<FieldSet>>
Parse the given source a selection set with optional outer brackets.
path is the filesystem path (or arbitrary string) used in diagnostics
to identify this source file to users.
Create a Parser to use different parser configuration.
sourcepub fn parse_and_validate(
schema: &Valid<Schema>,
type_name: NamedType,
source_text: impl Into<String>,
path: impl AsRef<Path>
) -> Result<Valid<Self>, WithErrors<Self>>
pub fn parse_and_validate( schema: &Valid<Schema>, type_name: NamedType, source_text: impl Into<String>, path: impl AsRef<Path> ) -> Result<Valid<Self>, WithErrors<Self>>
pub fn validate(&self, schema: &Valid<Schema>) -> Result<(), DiagnosticList>