pub struct ExecutableDocumentBuilder<'schema, 'errors> { /* private fields */ }Expand description
A builder for constructing an ExecutableDocument from multiple AST documents.
This builder allows you to parse and combine executable definitions (operations and fragments)
from multiple source files into a single ExecutableDocument.
Example
use apollo_compiler::{Schema, ExecutableDocument};
use apollo_compiler::parser::Parser;
use apollo_compiler::validation::DiagnosticList;
// Create a builder
let mut errors = DiagnosticList::new(Default::default());
let mut errors = DiagnosticList::new(Default::default());
let doc = ExecutableDocument::builder(Some(&schema), &mut errors)
.parse("query GetUser { user { id } }", "query1.graphql")
.parse("query GetMore { user { id } }", "query2.graphql")
.build();
assert!(errors.is_empty());
assert_eq!(doc.operations.named.len(), 2);Implementations
Sourceimpl<'schema, 'errors> ExecutableDocumentBuilder<'schema, 'errors>
impl<'schema, 'errors> ExecutableDocumentBuilder<'schema, 'errors>
Sourcepub fn new(
schema: Option<&'schema Schema>,
errors: &'errors mut DiagnosticList,
) -> Self
pub fn new( schema: Option<&'schema Schema>, errors: &'errors mut DiagnosticList, ) -> Self
Creates a new ExecutableDocumentBuilder.
Sourcepub fn parse(
self,
source_text: impl Into<String>,
path: impl AsRef<Path>,
) -> Self
pub fn parse( self, source_text: impl Into<String>, path: impl AsRef<Path>, ) -> Self
Parses a GraphQL executable document from source text and adds it to the builder.
This is a convenience method that creates a parser and calls
Parser::parse_into_executable_builder.
Sourcepub fn add_ast_document(
&mut self,
document: &Document,
type_system_definitions_are_errors: bool,
)
pub fn add_ast_document( &mut self, document: &Document, type_system_definitions_are_errors: bool, )
Adds an AST document to the executable document being built.
Sourcepub fn build(self) -> ExecutableDocument
pub fn build(self) -> ExecutableDocument
Returns the executable document built from all added AST documents.